==> haskell-css-text-0.1.3.0-335-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 css-text
version:              0.1.3.0
visibility:           public
id:                   css-text-0.1.3.0-8HZ7wBigw077TBROZ7zr0v
key:                  css-text-0.1.3.0-8HZ7wBigw077TBROZ7zr0v
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/yesodweb/css-text.git#readme
synopsis:             CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>

category:             Web, Yesod
abi:                  2288e0c8febb3b538d04a2d65bc4127f
exposed:              True
exposed-modules:      Text.CSS.Parse Text.CSS.Render
hidden-modules:       Paths_css_text
import-dirs:          /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-css-text
hs-libraries:         HScss-text-0.1.3.0-8HZ7wBigw077TBROZ7zr0v
depends:
    attoparsec-0.14.4-fEKSJrOU814GdIIzzkkyx base-4.17.2.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html:         /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-css-text-0.1.3.0-336-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 css-text
version:              0.1.3.0
visibility:           public
id:                   css-text-0.1.3.0-DBFFQJ4GCXhIZbCU2Bb9xz
key:                  css-text-0.1.3.0-DBFFQJ4GCXhIZbCU2Bb9xz
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/yesodweb/css-text.git#readme
synopsis:             CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>

category:             Web, Yesod
abi:                  71a9a18211ec3cf742f7d37a85e701f3
exposed:              True
exposed-modules:      Text.CSS.Parse Text.CSS.Render
hidden-modules:       Paths_css_text
import-dirs:          /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-css-text
hs-libraries:         HScss-text-0.1.3.0-DBFFQJ4GCXhIZbCU2Bb9xz
depends:
    attoparsec-0.14.4-K4GZo37SQ24KyCrR1RSIsH base-4.17.2.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html:         /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
